@@ -1,6 +1,6 @@
 /*
  * Calcurse - text-based organizer
- * Copyright (c) 2004-2005 Frederic Culot
+ * Copyright (c) 2004-2006 Frederic Culot
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,11 +22,18 @@
  *
  */
 
+#ifndef CALCURSE_ARGS_H
+#define CALCURSE_ARGS_H
+
 void usage();
-int parse_args(int argc, char **argv);
+void usage_try();
+int parse_args(int argc, char **argv, int colr);
 void version_arg();
 void help_arg();
-void todo_arg();
+void todo_arg(int colr);
 int app_arg(int add_line, int year, int month, int day, long date);
 void date_arg(char *ddate, int add_line);
 int check_date(char *date);
+void arg_print_date(long date);
+
+#endif /* CALCURSE_ARGS_H */
