@@ -1,6 +1,6 @@
 /*
  * Calcurse - text-based organizer
- * Copyright (c) 2004-2005 Frederic Culot
+ * Copyright (c) 2004-2006 Frederic Culot
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,12 +22,18 @@
  *
  */
 
-void update_cal_panel(int y_cal, int x_cal, int nl_cal,
+#ifndef CALCURSE_CALENDAR_H
+#define CALCURSE_CALENDAR_H
+
+#include <stdbool.h>
+
+void update_cal_panel(WINDOW *cwin, int nl_cal,
 		      int nc_cal, int sel_month, int sel_year, int sel_day,
-		      int day, int month, int year);
+		      int day, int month, int year,
+                      bool monday_first);
 int isBissextile(unsigned);
-static unsigned month_to_days(unsigned);
-static long years_to_days(unsigned);
 long ymd_to_scalar(unsigned, unsigned, unsigned);
 void goto_day(int colr, int day, int month, int year,
 	      int *sel_day, int *sel_month, int *sel_year);
+
+#endif /* CALCURSE_CALENDAR_H */
