@@ -1,6 +1,6 @@
 /*
  * Calcurse - text-based organizer
- * Copyright (c) 2004-2005 Frederic Culot
+ * Copyright (c) 2004-2006 Frederic Culot
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,6 +22,19 @@
  *
  */
 
-void config_bar(int colr);
+#ifndef CALCURSE_CUSTOM_H
+#define CALCURSE_CUSTOM_H
+
+struct attribute_s {
+	int color[7];
+	int nocolor[7];
+};
+
+void custom_init_attr(int colr);
+void custom_apply_attr(WINDOW *win, int attr_num);
+void custom_remove_attr(WINDOW *win, int attr_num);
+void config_bar();
 int layout_config(int layout, int colr);
 int color_config(int colr);
+
+#endif /* CALCURSE_CUSTOM_H */
