@@ -1,6 +1,6 @@
 /*
  * Calcurse - text-based organizer
- * Copyright (c) 2004-2005 Frederic Culot
+ * Copyright (c) 2004-2006 Frederic Culot
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,4 +22,18 @@
  *
  */
 
+#ifndef CALCURSE_HELP_H
+#define CALCURSE_HELP_H
+
+#include <ncurses.h>
+
+typedef struct {
+	char *title;
+	char *text;
+} help_page_t;
+
+int write_help_pad(WINDOW *win, char *title, char *text, int pad_width);
+int get_help_lines(char *text);
 void help_screen(int which_pan, int colr);
+
+#endif /* CALCURSE_HELP_H */
