@@ -1,6 +1,6 @@
 /*
  * Calcurse - text-based organizer
- * Copyright (c) 2004-2005 Frederic Culot
+ * Copyright (c) 2004-2006 Frederic Culot
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,10 +22,19 @@
  *
  */
 
-void io_init(char *cfile);
-void save_cal( char *auto_save, char *confirm_quit, char *confirm_delete,
-	      int colr, int layout);
+#ifndef CALCURSE_IO_H
+#define CALCURSE_IO_H
 
+void io_init(char *cfile);
+void extract_data(char *dst_data, const char *org, int len);
+void save_cal(bool auto_save, bool confirm_quit, 
+	 bool confirm_delete, bool skip_system_dialogs, 
+         bool skip_progress_bar, bool week_begins_on_monday, 
+	 int colr, int layout);
 void load_app();
-int load_todo();
-void check_data_files(int colr);
+int load_todo(int colr);
+int check_data_files();
+void startup_screen(bool skip_dialogs, int no_data_file, int colr);
+void progress_bar(bool save, int progress);
+
+#endif /* CALCURSE_IO_H */
