@@ -1,6 +1,6 @@
 /*
  * Calcurse - text-based organizer
- * Copyright (c) 2004-2005 Frederic Culot
+ * Copyright (c) 2004-2006 Frederic Culot
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,6 +25,8 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+
+#include "i18n.h"
 #include "todo.h"
 
 struct todo_s *todolist;
@@ -71,6 +73,6 @@ void todo_delete_bynum(unsigned num)
 		n++;
 	}
 	/* not reached */
-	fputs("todo_delete_bynum: no such todo_s\n", stderr);
-	exit(1);
+	fputs(_("FATAL ERROR in todo_delete_bynum: no such todo\n"), stderr);
+	exit(EXIT_FAILURE);
 }
