@@ -1,6 +1,6 @@
 /*
  * Calcurse - text-based organizer
- * Copyright (c) 2004-2005 Frederic Culot
+ * Copyright (c) 2004-2006 Frederic Culot
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,6 +22,9 @@
  *
  */
 
+#ifndef CALCURSE_TODO_H
+#define CALCURSE_TODO_H
+
 struct todo_s {
 	struct todo_s *next;
 	char *mesg;
@@ -32,3 +35,5 @@ extern struct todo_s *todolist;
 struct todo_s *todo_insert(char *mesg);
 struct todo_s *todo_add(char *mesg);
 void todo_delete_bynum(unsigned num);
+
+#endif /* CALCURSE_TODO_H */
