@@ -1,6 +1,6 @@
 /*
  * Calcurse - text-based organizer
- * Copyright (c) 2004-2005 Frederic Culot
+ * Copyright (c) 2004-2006 Frederic Culot
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,6 +22,7 @@
  *
  */
 
+#include "i18n.h"
 #include "vars.h"
 
 /*
@@ -29,21 +30,36 @@
  */
 int col = 0, row = 0;
 
+/* variable to tell if the terminal supports color */
+bool colorize = false;
+
 /*
  * variables to store calendar names
  */
 int days[12] = { 31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31 };
 char *monthnames[12] =
-    { "January", "February", "March", "April", "May", "June",
-	"July", "August", "September", "October", "November", "December"
-};
-char *daynames[8] =
-    { "Sun", "Mon", "Tue", "Wen", "Thu", "Fri", "Sat", "Sun" };
+    { N_("January"), 
+      N_("February"), 
+      N_("March"), 
+      N_("April"), 
+      N_("May"), 
+      N_("June"),
+      N_("July"), 
+      N_("August"), 
+      N_("September"), 
+      N_("October"), 
+      N_("November"), 
+      N_("December") };
 
-/*
- * variables to store texts
- */
-char arg_usage[56] = "Usage: calcurse [-h | -v] [-at] [-d date|num] [-c file]\n";
+char *daynames[8] =
+    { N_("Sun"), 
+      N_("Mon"), 
+      N_("Tue"), 
+      N_("Wed"), 
+      N_("Thu"), 
+      N_("Fri"), 
+      N_("Sat"), 
+      N_("Sun") };
 
 /* 
  * variables to store data path names, which are initialized in
@@ -53,3 +69,15 @@ char path_dir[] = "";
 char path_todo[] = "";
 char path_apts[] = "";
 char path_conf[] = "";
+
+/* 
+ * Variables to handle calcurse windows: 
+ * cwin = calendar window
+ * awin = appointment window
+ * twin = todo window
+ * swin = status bar window
+ */
+WINDOW *awin = NULL, *cwin = NULL, *twin = NULL, *swin = NULL;
+
+/* Variable to handle pads. */
+struct pad_s *apad;
